==> block2-0.3.0.tar.gz: block2-0.3.0/src/block2_dmrg.hpp <==

/*
 * block2: Efficient MPO implementation of quantum chemistry DMRG
 * Copyright (C) 2020-2021 Huanchen Zhai <hczhai@caltech.edu>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <https://www.gnu.org/licenses/>.
 *
 */

#pragma once

#include "dmrg/archived_mpo.hpp"
#include "dmrg/determinant.hpp"
#include "dmrg/effective_hamiltonian.hpp"
#include "dmrg/moving_environment.hpp"
#include "dmrg/mpo.hpp"
#include "dmrg/mpo_fusing.hpp"
#include "dmrg/mpo_simplification.hpp"
#include "dmrg/mps.hpp"
#include "dmrg/mps_unfused.hpp"
#include "dmrg/orbital_ordering.hpp"
#include "dmrg/parallel_mpo.hpp"
#include "dmrg/parallel_mps.hpp"
#include "dmrg/parallel_rule_sum_mpo.hpp"
#include "dmrg/partition.hpp"
#include "dmrg/qc_hamiltonian.hpp"
#include "dmrg/qc_mpo.hpp"
#include "dmrg/qc_ncorr.hpp"
#include "dmrg/qc_parallel_rule.hpp"
#include "dmrg/qc_pdm1.hpp"
#include "dmrg/qc_pdm2.hpp"
#include "dmrg/qc_rule.hpp"
#include "dmrg/qc_sum_mpo.hpp"
#include "dmrg/state_averaged.hpp"
#include "dmrg/sweep_algorithm.hpp"
#include "dmrg/sweep_algorithm_td.hpp"

#ifdef _EXPLICIT_TEMPLATE
#include "instantiation/block2_dmrg.hpp"
#endif

==> block2-0.5.3.tar.gz: block2-0.5.3/src/block2_dmrg.hpp <==

/*
 * block2: Efficient MPO implementation of quantum chemistry DMRG
 * Copyright (C) 2020-2021 Huanchen Zhai <hczhai@caltech.edu>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <https://www.gnu.org/licenses/>.
 *
 */

#pragma once

#include "dmrg/archived_mpo.hpp"
#include "dmrg/determinant.hpp"
#include "dmrg/dmrg_driver.hpp"
#include "dmrg/effective_functions.hpp"
#include "dmrg/effective_hamiltonian.hpp"
#include "dmrg/general_hamiltonian.hpp"
#include "dmrg/general_mpo.hpp"
#include "dmrg/general_npdm.hpp"
#include "dmrg/moving_environment.hpp"
#include "dmrg/mpo.hpp"
#include "dmrg/mpo_fusing.hpp"
#include "dmrg/mpo_simplification.hpp"
#include "dmrg/mps.hpp"
#include "dmrg/mps_unfused.hpp"
#include "dmrg/orbital_ordering.hpp"
#include "dmrg/parallel_mpo.hpp"
#include "dmrg/parallel_mps.hpp"
#include "dmrg/parallel_simple.hpp"
#include "dmrg/partition.hpp"
#include "dmrg/qc_hamiltonian.hpp"
#include "dmrg/qc_mpo.hpp"
#include "dmrg/qc_ncorr.hpp"
#include "dmrg/qc_parallel_rule.hpp"
#include "dmrg/qc_pdm1.hpp"
#include "dmrg/qc_pdm2.hpp"
#include "dmrg/qc_rule.hpp"
#include "dmrg/qc_sum_mpo.hpp"
#include "dmrg/state_averaged.hpp"
#include "dmrg/sweep_algorithm.hpp"
#include "dmrg/sweep_algorithm_td.hpp"

#ifdef _EXPLICIT_TEMPLATE
#include "instantiation/block2_dmrg.hpp"
#endif
